---
id: 20211123215420
title: Convert relative links to absolute
tags: [hyperlink, zettel, markdown]
---

# Convert relative links to absolute

Two syntaxes of links inside markdown documents are supported:

1. Markdown style: ```[title](url)```
2. Wiki style: ```[[url]]```

When linking to a markdown document which is a zettel, wiki-style links will be converted to markdown-style and the title of the target zettel will be used.

You can omit `.md` extension when linking to zettels. It will be added automatically.

Links are converted to absolute form. This is to avoid broken links in the resulting site.
